# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/grpc/hdmapimpl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import lane_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__pb2
from proto.hdmap_lib.proto import road_pb2 as proto_dot_hdmap__lib_dot_proto_dot_road__pb2
from proto.hdmap_lib.proto import junction_pb2 as proto_dot_hdmap__lib_dot_proto_dot_junction__pb2
from proto.hdmap_lib.proto import object_pb2 as proto_dot_hdmap__lib_dot_proto_dot_object__pb2
from proto.hdmap_lib.proto import poi_pb2 as proto_dot_hdmap__lib_dot_proto_dot_poi__pb2
from proto.hdmap_lib.proto import parking_space_pb2 as proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2
from proto.hdmap_lib.proto import relation_pb2 as proto_dot_hdmap__lib_dot_proto_dot_relation__pb2
from proto.hdmap_lib.proto import stop_line_pb2 as proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2
from proto.hdmap_lib.proto import signal_pb2 as proto_dot_hdmap__lib_dot_proto_dot_signal__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import crosswalk_pb2 as proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2
from proto.hdmap_lib.proto import lane_link_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/grpc/hdmapimpl.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=b'\n\032io.grpc.examples.hdmapimplB\016HdmapImplProtoP\001\242\002\002HI',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aproto/grpc/hdmapimpl.proto\x12\thdmap_lib\x1a proto/hdmap_lib/proto/lane.proto\x1a proto/hdmap_lib/proto/road.proto\x1a$proto/hdmap_lib/proto/junction.proto\x1a\"proto/hdmap_lib/proto/object.proto\x1a\x1fproto/hdmap_lib/proto/poi.proto\x1a)proto/hdmap_lib/proto/parking_space.proto\x1a$proto/hdmap_lib/proto/relation.proto\x1a%proto/hdmap_lib/proto/stop_line.proto\x1a\"proto/hdmap_lib/proto/signal.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a%proto/hdmap_lib/proto/crosswalk.proto\x1a%proto/hdmap_lib/proto/lane_link.proto\"<\n\x0eLoadMapRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\"E\n\x0cLoadMapReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x13\n\x0bload_status\x18\x02 \x01(\x08\x12\x0c\n\x04uuid\x18\x03 \x01(\t\"5\n\x11ReleaseMapRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"5\n\x0fReleaseMapReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\"b\n\x08PointENU\x12\x0e\n\x01x\x18\x01 \x01(\x01:\x03nan\x12\x0e\n\x01y\x18\x02 \x01(\x01:\x03nan\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\x12\x13\n\x08offset_x\x18\x04 \x01(\x01:\x01\x30\x12\x13\n\x08offset_y\x18\x05 \x01(\x01:\x01\x30\"\x93\x06\n\x06Vessel\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12!\n\x04head\x18\x03 \x01(\x0b\x32\x13.hdmap_lib.PointENU\x12!\n\x04rear\x18\x04 \x01(\x0b\x32\x13.hdmap_lib.PointENU\x12\x12\n\nhead_scale\x18\x14 \x01(\x05\x12\x12\n\nrear_scale\x18\x15 \x01(\x05\x12&\n\treal_head\x18\x05 \x01(\x0b\x32\x13.hdmap_lib.PointENU\x12&\n\treal_rear\x18\x06 \x01(\x0b\x32\x13.hdmap_lib.PointENU\x12\x17\n\x0freal_head_scale\x18\x16 \x01(\x05\x12\x17\n\x0freal_rear_scale\x18\x17 \x01(\x05\x12\x1a\n\x12virtual_lane_index\x18\x08 \x01(\x05\x12\x19\n\x11virtual_lane_rank\x18\t \x01(\x05\x12\x13\n\x0bhead_bridge\x18\n \x01(\t\x12\x14\n\x0cleave_bridge\x18\x0b \x01(\t\x12M\n\x1a\x65\x61st_area_girder_direction\x18\x0c \x01(\x0e\x32!.hdmap_lib.Vessel.GirderDirection:\x06NORMAL\x12U\n\"east_working_area_girder_direction\x18\r \x01(\x0e\x32!.hdmap_lib.Vessel.GirderDirection:\x06NORMAL\x12U\n\"west_working_area_girder_direction\x18\x0e \x01(\x0e\x32!.hdmap_lib.Vessel.GirderDirection:\x06NORMAL\x12M\n\x1awest_area_girder_direction\x18\x0f \x01(\x0e\x32!.hdmap_lib.Vessel.GirderDirection:\x06NORMAL\"H\n\x0fGirderDirection\x12\n\n\x06NORMAL\x10\x01\x12\x0b\n\x07REVERSE\x10\x02\x12\r\n\tBOTH_EAST\x10\x03\x12\r\n\tBOTH_WEST\x10\x04\"G\n\x0cVesselStatus\x12\x14\n\x0ctimestamp_ms\x18\x01 \x01(\x03\x12!\n\x06vessel\x18\x02 \x03(\x0b\x32\x11.hdmap_lib.Vessel\"a\n\rReloadRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12.\n\rvessel_status\x18\x03 \x01(\x0b\x32\x17.hdmap_lib.VesselStatus\"8\n\x0bReloadReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x15\n\rreload_status\x18\x02 \x01(\x08\"1\n\rGetMapRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"\xa3\x05\n\x0bGetMapReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12&\n\nlane_proto\x18\x02 \x03(\x0b\x32\x12.hdmap_lib.element\x12&\n\nroad_proto\x18\x03 \x03(\x0b\x32\x12.hdmap_lib.element\x12*\n\x0ejunction_proto\x18\x04 \x03(\x0b\x32\x12.hdmap_lib.element\x12(\n\x0cobject_proto\x18\x05 \x03(\x0b\x32\x12.hdmap_lib.element\x12%\n\tpoi_proto\x18\x06 \x03(\x0b\x32\x12.hdmap_lib.element\x12/\n\x13parking_space_proto\x18\x07 \x03(\x0b\x32\x12.hdmap_lib.element\x12\x32\n\x16pull_over_region_proto\x18\x08 \x03(\x0b\x32\x12.hdmap_lib.element\x12+\n\x0f\x63rosswalk_proto\x18\t \x03(\x0b\x32\x12.hdmap_lib.element\x12+\n\x0fstop_line_proto\x18\n \x03(\x0b\x32\x12.hdmap_lib.element\x12(\n\x0csignal_proto\x18\x0b \x03(\x0b\x32\x12.hdmap_lib.element\x12\x30\n\x05lines\x18\x0c \x03(\x0b\x32!.hdmap_lib.GetMapReply.LinesEntry\x12&\n\trelations\x18\r \x03(\x0b\x32\x13.hdmap_lib.Relation\x12\'\n\nlane_links\x18\x0e \x03(\x0b\x32\x13.hdmap_lib.LaneLink\x1aG\n\nLinesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hdmap_lib.LineStringData:\x02\x38\x01\"d\n\x15GetElementByIdRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x13\n\x0b\x65lement_ids\x18\x03 \x03(\x03\x12\x14\n\x0c\x65lement_type\x18\x04 \x01(\t\"\xe8\x03\n\x07\x65lement\x12%\n\nlane_proto\x18\x01 \x01(\x0b\x32\x0f.hdmap_lib.LaneH\x00\x12%\n\nroad_proto\x18\x02 \x01(\x0b\x32\x0f.hdmap_lib.RoadH\x00\x12-\n\x0ejunction_proto\x18\x03 \x01(\x0b\x32\x13.hdmap_lib.JunctionH\x00\x12)\n\x0cobject_proto\x18\x04 \x01(\x0b\x32\x11.hdmap_lib.ObjectH\x00\x12#\n\tpoi_proto\x18\x05 \x01(\x0b\x32\x0e.hdmap_lib.PoiH\x00\x12\x36\n\x13parking_space_proto\x18\x06 \x01(\x0b\x32\x17.hdmap_lib.ParkingSpaceH\x00\x12;\n\x16pull_over_region_proto\x18\x07 \x01(\x0b\x32\x19.hdmap_lib.PullOverRegionH\x00\x12/\n\x0f\x63rosswalk_proto\x18\x08 \x01(\x0b\x32\x14.hdmap_lib.CrosswalkH\x00\x12.\n\x0fstop_line_proto\x18\t \x01(\x0b\x32\x13.hdmap_lib.StopLineH\x00\x12)\n\x0csignal_proto\x18\n \x01(\x0b\x32\x11.hdmap_lib.SignalH\x00\x42\x0f\n\relement_proto\"\xb8\x02\n\x13GetElementByIdReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12)\n\relement_proto\x18\x03 \x03(\x0b\x32\x12.hdmap_lib.element\x12\x38\n\x05lines\x18\x04 \x03(\x0b\x32).hdmap_lib.GetElementByIdReply.LinesEntry\x12&\n\trelations\x18\x05 \x03(\x0b\x32\x13.hdmap_lib.Relation\x12\'\n\nlane_links\x18\x06 \x03(\x0b\x32\x13.hdmap_lib.LaneLink\x1aG\n\nLinesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hdmap_lib.LineStringData:\x02\x38\x01\"r\n\x12GetElementsRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\x14\n\x0c\x65lement_type\x18\x05 \x01(\t\x12\x0e\n\x06radius\x18\x06 \x01(\x01\"\xb2\x02\n\x10GetElementsReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12)\n\relement_proto\x18\x03 \x03(\x0b\x32\x12.hdmap_lib.element\x12\x35\n\x05lines\x18\x04 \x03(\x0b\x32&.hdmap_lib.GetElementsReply.LinesEntry\x12&\n\trelations\x18\x05 \x03(\x0b\x32\x13.hdmap_lib.Relation\x12\'\n\nlane_links\x18\x06 \x03(\x0b\x32\x13.hdmap_lib.LaneLink\x1aG\n\nLinesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hdmap_lib.LineStringData:\x02\x38\x01\"_\n\x14GetProjectionRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07lane_id\x18\x03 \x01(\x03\x12\t\n\x01x\x18\x04 \x01(\x01\x12\t\n\x01y\x18\x05 \x01(\x01\"N\n\x12GetProjectionReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\t\n\x01s\x18\x03 \x01(\x01\x12\t\n\x01\x64\x18\x04 \x01(\x01\"Z\n\x0fGetPointRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07lane_id\x18\x03 \x01(\x03\x12\t\n\x01s\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01\"I\n\rGetPointReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\"Q\n\x11GetHeadingRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07lane_id\x18\x03 \x01(\x03\x12\t\n\x01s\x18\x04 \x01(\x01\"F\n\x0fGetHeadingReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\x0f\n\x07heading\x18\x03 \x01(\x01\"O\n\x0fGetWidthRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07lane_id\x18\x03 \x01(\x03\x12\t\n\x01s\x18\x04 \x01(\x01\"\\\n\rGetWidthReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\x12\n\nleft_width\x18\x03 \x01(\x01\x12\x13\n\x0bright_width\x18\x04 \x01(\x01\"S\n\x13GetRoadWidthRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07lane_id\x18\x03 \x01(\x03\x12\t\n\x01s\x18\x04 \x01(\x01\"`\n\x11GetRoadWidthReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\x12\n\nleft_width\x18\x03 \x01(\x01\x12\x13\n\x0bright_width\x18\x04 \x01(\x01\"s\n\x17GetRelativeWidthRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0f\n\x07lane_id\x18\x03 \x01(\x03\x12\t\n\x01x\x18\x04 \x01(\x01\x12\t\n\x01y\x18\x05 \x01(\x01\x12\x0f\n\x07heading\x18\x06 \x01(\x01\"v\n\x15GetRelativeWidthReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\x1b\n\x13left_relative_width\x18\x03 \x01(\x01\x12\x1c\n\x14right_relative_width\x18\x04 \x01(\x01\x32\x86\x07\n\tHdmapImpl\x12?\n\x07LoadMap\x12\x19.hdmap_lib.LoadMapRequest\x1a\x17.hdmap_lib.LoadMapReply\"\x00\x12H\n\nReleaseMap\x12\x1c.hdmap_lib.ReleaseMapRequest\x1a\x1a.hdmap_lib.ReleaseMapReply\"\x00\x12<\n\x06Reload\x12\x18.hdmap_lib.ReloadRequest\x1a\x16.hdmap_lib.ReloadReply\"\x00\x12<\n\x06GetMap\x12\x18.hdmap_lib.GetMapRequest\x1a\x16.hdmap_lib.GetMapReply\"\x00\x12T\n\x0eGetElementById\x12 .hdmap_lib.GetElementByIdRequest\x1a\x1e.hdmap_lib.GetElementByIdReply\"\x00\x12K\n\x0bGetElements\x12\x1d.hdmap_lib.GetElementsRequest\x1a\x1b.hdmap_lib.GetElementsReply\"\x00\x12Q\n\rGetprojection\x12\x1f.hdmap_lib.GetProjectionRequest\x1a\x1d.hdmap_lib.GetProjectionReply\"\x00\x12\x42\n\x08GetPoint\x12\x1a.hdmap_lib.GetPointRequest\x1a\x18.hdmap_lib.GetPointReply\"\x00\x12H\n\nGetHeading\x12\x1c.hdmap_lib.GetHeadingRequest\x1a\x1a.hdmap_lib.GetHeadingReply\"\x00\x12\x42\n\x08GetWidth\x12\x1a.hdmap_lib.GetWidthRequest\x1a\x18.hdmap_lib.GetWidthReply\"\x00\x12N\n\x0cGetRoadWidth\x12\x1e.hdmap_lib.GetRoadWidthRequest\x1a\x1c.hdmap_lib.GetRoadWidthReply\"\x00\x12Z\n\x10GetRelativeWidth\x12\".hdmap_lib.GetRelativeWidthRequest\x1a .hdmap_lib.GetRelativeWidthReply\"\x00\x42\x33\n\x1aio.grpc.examples.hdmapimplB\x0eHdmapImplProtoP\x01\xa2\x02\x02HI'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_lane__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_road__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_junction__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_object__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_poi__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_relation__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_signal__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2.DESCRIPTOR,])



_VESSEL_GIRDERDIRECTION = _descriptor.EnumDescriptor(
  name='GirderDirection',
  full_name='hdmap_lib.Vessel.GirderDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REVERSE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOTH_EAST', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOTH_WEST', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1547,
  serialized_end=1619,
)
_sym_db.RegisterEnumDescriptor(_VESSEL_GIRDERDIRECTION)


_LOADMAPREQUEST = _descriptor.Descriptor(
  name='LoadMapRequest',
  full_name='hdmap_lib.LoadMapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.LoadMapRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.LoadMapRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=548,
)


_LOADMAPREPLY = _descriptor.Descriptor(
  name='LoadMapReply',
  full_name='hdmap_lib.LoadMapReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.LoadMapReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_status', full_name='hdmap_lib.LoadMapReply.load_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.LoadMapReply.uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=619,
)


_RELEASEMAPREQUEST = _descriptor.Descriptor(
  name='ReleaseMapRequest',
  full_name='hdmap_lib.ReleaseMapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.ReleaseMapRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.ReleaseMapRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=674,
)


_RELEASEMAPREPLY = _descriptor.Descriptor(
  name='ReleaseMapReply',
  full_name='hdmap_lib.ReleaseMapReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.ReleaseMapReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.ReleaseMapReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=729,
)


_POINTENU = _descriptor.Descriptor(
  name='PointENU',
  full_name='hdmap_lib.PointENU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.PointENU.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.PointENU.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='hdmap_lib.PointENU.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset_x', full_name='hdmap_lib.PointENU.offset_x', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset_y', full_name='hdmap_lib.PointENU.offset_y', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=829,
)


_VESSEL = _descriptor.Descriptor(
  name='Vessel',
  full_name='hdmap_lib.Vessel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.Vessel.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='hdmap_lib.Vessel.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head', full_name='hdmap_lib.Vessel.head', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear', full_name='hdmap_lib.Vessel.rear', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_scale', full_name='hdmap_lib.Vessel.head_scale', index=4,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_scale', full_name='hdmap_lib.Vessel.rear_scale', index=5,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_head', full_name='hdmap_lib.Vessel.real_head', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_rear', full_name='hdmap_lib.Vessel.real_rear', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_head_scale', full_name='hdmap_lib.Vessel.real_head_scale', index=8,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_rear_scale', full_name='hdmap_lib.Vessel.real_rear_scale', index=9,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_lane_index', full_name='hdmap_lib.Vessel.virtual_lane_index', index=10,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_lane_rank', full_name='hdmap_lib.Vessel.virtual_lane_rank', index=11,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_bridge', full_name='hdmap_lib.Vessel.head_bridge', index=12,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leave_bridge', full_name='hdmap_lib.Vessel.leave_bridge', index=13,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_area_girder_direction', full_name='hdmap_lib.Vessel.east_area_girder_direction', index=14,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_working_area_girder_direction', full_name='hdmap_lib.Vessel.east_working_area_girder_direction', index=15,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_working_area_girder_direction', full_name='hdmap_lib.Vessel.west_working_area_girder_direction', index=16,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_area_girder_direction', full_name='hdmap_lib.Vessel.west_area_girder_direction', index=17,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VESSEL_GIRDERDIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=832,
  serialized_end=1619,
)


_VESSELSTATUS = _descriptor.Descriptor(
  name='VesselStatus',
  full_name='hdmap_lib.VesselStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_ms', full_name='hdmap_lib.VesselStatus.timestamp_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel', full_name='hdmap_lib.VesselStatus.vessel', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1621,
  serialized_end=1692,
)


_RELOADREQUEST = _descriptor.Descriptor(
  name='ReloadRequest',
  full_name='hdmap_lib.ReloadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.ReloadRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.ReloadRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_status', full_name='hdmap_lib.ReloadRequest.vessel_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1694,
  serialized_end=1791,
)


_RELOADREPLY = _descriptor.Descriptor(
  name='ReloadReply',
  full_name='hdmap_lib.ReloadReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.ReloadReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reload_status', full_name='hdmap_lib.ReloadReply.reload_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1849,
)


_GETMAPREQUEST = _descriptor.Descriptor(
  name='GetMapRequest',
  full_name='hdmap_lib.GetMapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetMapRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetMapRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1851,
  serialized_end=1900,
)


_GETMAPREPLY_LINESENTRY = _descriptor.Descriptor(
  name='LinesEntry',
  full_name='hdmap_lib.GetMapReply.LinesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.GetMapReply.LinesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.GetMapReply.LinesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2507,
  serialized_end=2578,
)

_GETMAPREPLY = _descriptor.Descriptor(
  name='GetMapReply',
  full_name='hdmap_lib.GetMapReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetMapReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_proto', full_name='hdmap_lib.GetMapReply.lane_proto', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_proto', full_name='hdmap_lib.GetMapReply.road_proto', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_proto', full_name='hdmap_lib.GetMapReply.junction_proto', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_proto', full_name='hdmap_lib.GetMapReply.object_proto', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_proto', full_name='hdmap_lib.GetMapReply.poi_proto', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space_proto', full_name='hdmap_lib.GetMapReply.parking_space_proto', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_region_proto', full_name='hdmap_lib.GetMapReply.pull_over_region_proto', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk_proto', full_name='hdmap_lib.GetMapReply.crosswalk_proto', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line_proto', full_name='hdmap_lib.GetMapReply.stop_line_proto', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_proto', full_name='hdmap_lib.GetMapReply.signal_proto', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.GetMapReply.lines', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='hdmap_lib.GetMapReply.relations', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_links', full_name='hdmap_lib.GetMapReply.lane_links', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETMAPREPLY_LINESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1903,
  serialized_end=2578,
)


_GETELEMENTBYIDREQUEST = _descriptor.Descriptor(
  name='GetElementByIdRequest',
  full_name='hdmap_lib.GetElementByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElementByIdRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetElementByIdRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_ids', full_name='hdmap_lib.GetElementByIdRequest.element_ids', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_type', full_name='hdmap_lib.GetElementByIdRequest.element_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2580,
  serialized_end=2680,
)


_ELEMENT = _descriptor.Descriptor(
  name='element',
  full_name='hdmap_lib.element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_proto', full_name='hdmap_lib.element.lane_proto', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_proto', full_name='hdmap_lib.element.road_proto', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_proto', full_name='hdmap_lib.element.junction_proto', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_proto', full_name='hdmap_lib.element.object_proto', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_proto', full_name='hdmap_lib.element.poi_proto', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space_proto', full_name='hdmap_lib.element.parking_space_proto', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_region_proto', full_name='hdmap_lib.element.pull_over_region_proto', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk_proto', full_name='hdmap_lib.element.crosswalk_proto', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line_proto', full_name='hdmap_lib.element.stop_line_proto', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_proto', full_name='hdmap_lib.element.signal_proto', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='element_proto', full_name='hdmap_lib.element.element_proto',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2683,
  serialized_end=3171,
)


_GETELEMENTBYIDREPLY_LINESENTRY = _descriptor.Descriptor(
  name='LinesEntry',
  full_name='hdmap_lib.GetElementByIdReply.LinesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.GetElementByIdReply.LinesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.GetElementByIdReply.LinesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2507,
  serialized_end=2578,
)

_GETELEMENTBYIDREPLY = _descriptor.Descriptor(
  name='GetElementByIdReply',
  full_name='hdmap_lib.GetElementByIdReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElementByIdReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetElementByIdReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_proto', full_name='hdmap_lib.GetElementByIdReply.element_proto', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.GetElementByIdReply.lines', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='hdmap_lib.GetElementByIdReply.relations', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_links', full_name='hdmap_lib.GetElementByIdReply.lane_links', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETELEMENTBYIDREPLY_LINESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3174,
  serialized_end=3486,
)


_GETELEMENTSREQUEST = _descriptor.Descriptor(
  name='GetElementsRequest',
  full_name='hdmap_lib.GetElementsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElementsRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetElementsRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.GetElementsRequest.x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.GetElementsRequest.y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_type', full_name='hdmap_lib.GetElementsRequest.element_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='hdmap_lib.GetElementsRequest.radius', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3488,
  serialized_end=3602,
)


_GETELEMENTSREPLY_LINESENTRY = _descriptor.Descriptor(
  name='LinesEntry',
  full_name='hdmap_lib.GetElementsReply.LinesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.GetElementsReply.LinesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.GetElementsReply.LinesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2507,
  serialized_end=2578,
)

_GETELEMENTSREPLY = _descriptor.Descriptor(
  name='GetElementsReply',
  full_name='hdmap_lib.GetElementsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElementsReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetElementsReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element_proto', full_name='hdmap_lib.GetElementsReply.element_proto', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.GetElementsReply.lines', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='hdmap_lib.GetElementsReply.relations', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_links', full_name='hdmap_lib.GetElementsReply.lane_links', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETELEMENTSREPLY_LINESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3605,
  serialized_end=3911,
)


_GETPROJECTIONREQUEST = _descriptor.Descriptor(
  name='GetProjectionRequest',
  full_name='hdmap_lib.GetProjectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetProjectionRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetProjectionRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.GetProjectionRequest.lane_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.GetProjectionRequest.x', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.GetProjectionRequest.y', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3913,
  serialized_end=4008,
)


_GETPROJECTIONREPLY = _descriptor.Descriptor(
  name='GetProjectionReply',
  full_name='hdmap_lib.GetProjectionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetProjectionReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetProjectionReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.GetProjectionReply.s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='hdmap_lib.GetProjectionReply.d', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4010,
  serialized_end=4088,
)


_GETPOINTREQUEST = _descriptor.Descriptor(
  name='GetPointRequest',
  full_name='hdmap_lib.GetPointRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetPointRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetPointRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.GetPointRequest.lane_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.GetPointRequest.s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='hdmap_lib.GetPointRequest.d', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4090,
  serialized_end=4180,
)


_GETPOINTREPLY = _descriptor.Descriptor(
  name='GetPointReply',
  full_name='hdmap_lib.GetPointReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetPointReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetPointReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.GetPointReply.x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.GetPointReply.y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4182,
  serialized_end=4255,
)


_GETHEADINGREQUEST = _descriptor.Descriptor(
  name='GetHeadingRequest',
  full_name='hdmap_lib.GetHeadingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetHeadingRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetHeadingRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.GetHeadingRequest.lane_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.GetHeadingRequest.s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4257,
  serialized_end=4338,
)


_GETHEADINGREPLY = _descriptor.Descriptor(
  name='GetHeadingReply',
  full_name='hdmap_lib.GetHeadingReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetHeadingReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetHeadingReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='hdmap_lib.GetHeadingReply.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4340,
  serialized_end=4410,
)


_GETWIDTHREQUEST = _descriptor.Descriptor(
  name='GetWidthRequest',
  full_name='hdmap_lib.GetWidthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetWidthRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetWidthRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.GetWidthRequest.lane_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.GetWidthRequest.s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4412,
  serialized_end=4491,
)


_GETWIDTHREPLY = _descriptor.Descriptor(
  name='GetWidthReply',
  full_name='hdmap_lib.GetWidthReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetWidthReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetWidthReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_width', full_name='hdmap_lib.GetWidthReply.left_width', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_width', full_name='hdmap_lib.GetWidthReply.right_width', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4493,
  serialized_end=4585,
)


_GETROADWIDTHREQUEST = _descriptor.Descriptor(
  name='GetRoadWidthRequest',
  full_name='hdmap_lib.GetRoadWidthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetRoadWidthRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetRoadWidthRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.GetRoadWidthRequest.lane_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.GetRoadWidthRequest.s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4587,
  serialized_end=4670,
)


_GETROADWIDTHREPLY = _descriptor.Descriptor(
  name='GetRoadWidthReply',
  full_name='hdmap_lib.GetRoadWidthReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetRoadWidthReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetRoadWidthReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_width', full_name='hdmap_lib.GetRoadWidthReply.left_width', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_width', full_name='hdmap_lib.GetRoadWidthReply.right_width', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4672,
  serialized_end=4768,
)


_GETRELATIVEWIDTHREQUEST = _descriptor.Descriptor(
  name='GetRelativeWidthRequest',
  full_name='hdmap_lib.GetRelativeWidthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetRelativeWidthRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.GetRelativeWidthRequest.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.GetRelativeWidthRequest.lane_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.GetRelativeWidthRequest.x', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.GetRelativeWidthRequest.y', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='hdmap_lib.GetRelativeWidthRequest.heading', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4770,
  serialized_end=4885,
)


_GETRELATIVEWIDTHREPLY = _descriptor.Descriptor(
  name='GetRelativeWidthReply',
  full_name='hdmap_lib.GetRelativeWidthReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetRelativeWidthReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetRelativeWidthReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_relative_width', full_name='hdmap_lib.GetRelativeWidthReply.left_relative_width', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_relative_width', full_name='hdmap_lib.GetRelativeWidthReply.right_relative_width', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4887,
  serialized_end=5005,
)

_VESSEL.fields_by_name['head'].message_type = _POINTENU
_VESSEL.fields_by_name['rear'].message_type = _POINTENU
_VESSEL.fields_by_name['real_head'].message_type = _POINTENU
_VESSEL.fields_by_name['real_rear'].message_type = _POINTENU
_VESSEL.fields_by_name['east_area_girder_direction'].enum_type = _VESSEL_GIRDERDIRECTION
_VESSEL.fields_by_name['east_working_area_girder_direction'].enum_type = _VESSEL_GIRDERDIRECTION
_VESSEL.fields_by_name['west_working_area_girder_direction'].enum_type = _VESSEL_GIRDERDIRECTION
_VESSEL.fields_by_name['west_area_girder_direction'].enum_type = _VESSEL_GIRDERDIRECTION
_VESSEL_GIRDERDIRECTION.containing_type = _VESSEL
_VESSELSTATUS.fields_by_name['vessel'].message_type = _VESSEL
_RELOADREQUEST.fields_by_name['vessel_status'].message_type = _VESSELSTATUS
_GETMAPREPLY_LINESENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._LINESTRINGDATA
_GETMAPREPLY_LINESENTRY.containing_type = _GETMAPREPLY
_GETMAPREPLY.fields_by_name['lane_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['road_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['junction_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['object_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['poi_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['parking_space_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['pull_over_region_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['crosswalk_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['stop_line_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['signal_proto'].message_type = _ELEMENT
_GETMAPREPLY.fields_by_name['lines'].message_type = _GETMAPREPLY_LINESENTRY
_GETMAPREPLY.fields_by_name['relations'].message_type = proto_dot_hdmap__lib_dot_proto_dot_relation__pb2._RELATION
_GETMAPREPLY.fields_by_name['lane_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2._LANELINK
_ELEMENT.fields_by_name['lane_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__pb2._LANE
_ELEMENT.fields_by_name['road_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_road__pb2._ROAD
_ELEMENT.fields_by_name['junction_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_junction__pb2._JUNCTION
_ELEMENT.fields_by_name['object_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_object__pb2._OBJECT
_ELEMENT.fields_by_name['poi_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_poi__pb2._POI
_ELEMENT.fields_by_name['parking_space_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PARKINGSPACE
_ELEMENT.fields_by_name['pull_over_region_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PULLOVERREGION
_ELEMENT.fields_by_name['crosswalk_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2._CROSSWALK
_ELEMENT.fields_by_name['stop_line_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2._STOPLINE
_ELEMENT.fields_by_name['signal_proto'].message_type = proto_dot_hdmap__lib_dot_proto_dot_signal__pb2._SIGNAL
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['lane_proto'])
_ELEMENT.fields_by_name['lane_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['road_proto'])
_ELEMENT.fields_by_name['road_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['junction_proto'])
_ELEMENT.fields_by_name['junction_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['object_proto'])
_ELEMENT.fields_by_name['object_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['poi_proto'])
_ELEMENT.fields_by_name['poi_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['parking_space_proto'])
_ELEMENT.fields_by_name['parking_space_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['pull_over_region_proto'])
_ELEMENT.fields_by_name['pull_over_region_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['crosswalk_proto'])
_ELEMENT.fields_by_name['crosswalk_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['stop_line_proto'])
_ELEMENT.fields_by_name['stop_line_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_ELEMENT.oneofs_by_name['element_proto'].fields.append(
  _ELEMENT.fields_by_name['signal_proto'])
_ELEMENT.fields_by_name['signal_proto'].containing_oneof = _ELEMENT.oneofs_by_name['element_proto']
_GETELEMENTBYIDREPLY_LINESENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._LINESTRINGDATA
_GETELEMENTBYIDREPLY_LINESENTRY.containing_type = _GETELEMENTBYIDREPLY
_GETELEMENTBYIDREPLY.fields_by_name['element_proto'].message_type = _ELEMENT
_GETELEMENTBYIDREPLY.fields_by_name['lines'].message_type = _GETELEMENTBYIDREPLY_LINESENTRY
_GETELEMENTBYIDREPLY.fields_by_name['relations'].message_type = proto_dot_hdmap__lib_dot_proto_dot_relation__pb2._RELATION
_GETELEMENTBYIDREPLY.fields_by_name['lane_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2._LANELINK
_GETELEMENTSREPLY_LINESENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._LINESTRINGDATA
_GETELEMENTSREPLY_LINESENTRY.containing_type = _GETELEMENTSREPLY
_GETELEMENTSREPLY.fields_by_name['element_proto'].message_type = _ELEMENT
_GETELEMENTSREPLY.fields_by_name['lines'].message_type = _GETELEMENTSREPLY_LINESENTRY
_GETELEMENTSREPLY.fields_by_name['relations'].message_type = proto_dot_hdmap__lib_dot_proto_dot_relation__pb2._RELATION
_GETELEMENTSREPLY.fields_by_name['lane_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2._LANELINK
DESCRIPTOR.message_types_by_name['LoadMapRequest'] = _LOADMAPREQUEST
DESCRIPTOR.message_types_by_name['LoadMapReply'] = _LOADMAPREPLY
DESCRIPTOR.message_types_by_name['ReleaseMapRequest'] = _RELEASEMAPREQUEST
DESCRIPTOR.message_types_by_name['ReleaseMapReply'] = _RELEASEMAPREPLY
DESCRIPTOR.message_types_by_name['PointENU'] = _POINTENU
DESCRIPTOR.message_types_by_name['Vessel'] = _VESSEL
DESCRIPTOR.message_types_by_name['VesselStatus'] = _VESSELSTATUS
DESCRIPTOR.message_types_by_name['ReloadRequest'] = _RELOADREQUEST
DESCRIPTOR.message_types_by_name['ReloadReply'] = _RELOADREPLY
DESCRIPTOR.message_types_by_name['GetMapRequest'] = _GETMAPREQUEST
DESCRIPTOR.message_types_by_name['GetMapReply'] = _GETMAPREPLY
DESCRIPTOR.message_types_by_name['GetElementByIdRequest'] = _GETELEMENTBYIDREQUEST
DESCRIPTOR.message_types_by_name['element'] = _ELEMENT
DESCRIPTOR.message_types_by_name['GetElementByIdReply'] = _GETELEMENTBYIDREPLY
DESCRIPTOR.message_types_by_name['GetElementsRequest'] = _GETELEMENTSREQUEST
DESCRIPTOR.message_types_by_name['GetElementsReply'] = _GETELEMENTSREPLY
DESCRIPTOR.message_types_by_name['GetProjectionRequest'] = _GETPROJECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetProjectionReply'] = _GETPROJECTIONREPLY
DESCRIPTOR.message_types_by_name['GetPointRequest'] = _GETPOINTREQUEST
DESCRIPTOR.message_types_by_name['GetPointReply'] = _GETPOINTREPLY
DESCRIPTOR.message_types_by_name['GetHeadingRequest'] = _GETHEADINGREQUEST
DESCRIPTOR.message_types_by_name['GetHeadingReply'] = _GETHEADINGREPLY
DESCRIPTOR.message_types_by_name['GetWidthRequest'] = _GETWIDTHREQUEST
DESCRIPTOR.message_types_by_name['GetWidthReply'] = _GETWIDTHREPLY
DESCRIPTOR.message_types_by_name['GetRoadWidthRequest'] = _GETROADWIDTHREQUEST
DESCRIPTOR.message_types_by_name['GetRoadWidthReply'] = _GETROADWIDTHREPLY
DESCRIPTOR.message_types_by_name['GetRelativeWidthRequest'] = _GETRELATIVEWIDTHREQUEST
DESCRIPTOR.message_types_by_name['GetRelativeWidthReply'] = _GETRELATIVEWIDTHREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoadMapRequest = _reflection.GeneratedProtocolMessageType('LoadMapRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADMAPREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LoadMapRequest)
  })
_sym_db.RegisterMessage(LoadMapRequest)

LoadMapReply = _reflection.GeneratedProtocolMessageType('LoadMapReply', (_message.Message,), {
  'DESCRIPTOR' : _LOADMAPREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LoadMapReply)
  })
_sym_db.RegisterMessage(LoadMapReply)

ReleaseMapRequest = _reflection.GeneratedProtocolMessageType('ReleaseMapRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASEMAPREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ReleaseMapRequest)
  })
_sym_db.RegisterMessage(ReleaseMapRequest)

ReleaseMapReply = _reflection.GeneratedProtocolMessageType('ReleaseMapReply', (_message.Message,), {
  'DESCRIPTOR' : _RELEASEMAPREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ReleaseMapReply)
  })
_sym_db.RegisterMessage(ReleaseMapReply)

PointENU = _reflection.GeneratedProtocolMessageType('PointENU', (_message.Message,), {
  'DESCRIPTOR' : _POINTENU,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PointENU)
  })
_sym_db.RegisterMessage(PointENU)

Vessel = _reflection.GeneratedProtocolMessageType('Vessel', (_message.Message,), {
  'DESCRIPTOR' : _VESSEL,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Vessel)
  })
_sym_db.RegisterMessage(Vessel)

VesselStatus = _reflection.GeneratedProtocolMessageType('VesselStatus', (_message.Message,), {
  'DESCRIPTOR' : _VESSELSTATUS,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.VesselStatus)
  })
_sym_db.RegisterMessage(VesselStatus)

ReloadRequest = _reflection.GeneratedProtocolMessageType('ReloadRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELOADREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ReloadRequest)
  })
_sym_db.RegisterMessage(ReloadRequest)

ReloadReply = _reflection.GeneratedProtocolMessageType('ReloadReply', (_message.Message,), {
  'DESCRIPTOR' : _RELOADREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ReloadReply)
  })
_sym_db.RegisterMessage(ReloadReply)

GetMapRequest = _reflection.GeneratedProtocolMessageType('GetMapRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMAPREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetMapRequest)
  })
_sym_db.RegisterMessage(GetMapRequest)

GetMapReply = _reflection.GeneratedProtocolMessageType('GetMapReply', (_message.Message,), {

  'LinesEntry' : _reflection.GeneratedProtocolMessageType('LinesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMAPREPLY_LINESENTRY,
    '__module__' : 'proto.grpc.hdmapimpl_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.GetMapReply.LinesEntry)
    })
  ,
  'DESCRIPTOR' : _GETMAPREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetMapReply)
  })
_sym_db.RegisterMessage(GetMapReply)
_sym_db.RegisterMessage(GetMapReply.LinesEntry)

GetElementByIdRequest = _reflection.GeneratedProtocolMessageType('GetElementByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTBYIDREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementByIdRequest)
  })
_sym_db.RegisterMessage(GetElementByIdRequest)

element = _reflection.GeneratedProtocolMessageType('element', (_message.Message,), {
  'DESCRIPTOR' : _ELEMENT,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.element)
  })
_sym_db.RegisterMessage(element)

GetElementByIdReply = _reflection.GeneratedProtocolMessageType('GetElementByIdReply', (_message.Message,), {

  'LinesEntry' : _reflection.GeneratedProtocolMessageType('LinesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETELEMENTBYIDREPLY_LINESENTRY,
    '__module__' : 'proto.grpc.hdmapimpl_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementByIdReply.LinesEntry)
    })
  ,
  'DESCRIPTOR' : _GETELEMENTBYIDREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementByIdReply)
  })
_sym_db.RegisterMessage(GetElementByIdReply)
_sym_db.RegisterMessage(GetElementByIdReply.LinesEntry)

GetElementsRequest = _reflection.GeneratedProtocolMessageType('GetElementsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTSREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementsRequest)
  })
_sym_db.RegisterMessage(GetElementsRequest)

GetElementsReply = _reflection.GeneratedProtocolMessageType('GetElementsReply', (_message.Message,), {

  'LinesEntry' : _reflection.GeneratedProtocolMessageType('LinesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETELEMENTSREPLY_LINESENTRY,
    '__module__' : 'proto.grpc.hdmapimpl_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementsReply.LinesEntry)
    })
  ,
  'DESCRIPTOR' : _GETELEMENTSREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementsReply)
  })
_sym_db.RegisterMessage(GetElementsReply)
_sym_db.RegisterMessage(GetElementsReply.LinesEntry)

GetProjectionRequest = _reflection.GeneratedProtocolMessageType('GetProjectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTIONREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetProjectionRequest)
  })
_sym_db.RegisterMessage(GetProjectionRequest)

GetProjectionReply = _reflection.GeneratedProtocolMessageType('GetProjectionReply', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTIONREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetProjectionReply)
  })
_sym_db.RegisterMessage(GetProjectionReply)

GetPointRequest = _reflection.GeneratedProtocolMessageType('GetPointRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOINTREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetPointRequest)
  })
_sym_db.RegisterMessage(GetPointRequest)

GetPointReply = _reflection.GeneratedProtocolMessageType('GetPointReply', (_message.Message,), {
  'DESCRIPTOR' : _GETPOINTREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetPointReply)
  })
_sym_db.RegisterMessage(GetPointReply)

GetHeadingRequest = _reflection.GeneratedProtocolMessageType('GetHeadingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETHEADINGREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetHeadingRequest)
  })
_sym_db.RegisterMessage(GetHeadingRequest)

GetHeadingReply = _reflection.GeneratedProtocolMessageType('GetHeadingReply', (_message.Message,), {
  'DESCRIPTOR' : _GETHEADINGREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetHeadingReply)
  })
_sym_db.RegisterMessage(GetHeadingReply)

GetWidthRequest = _reflection.GeneratedProtocolMessageType('GetWidthRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWIDTHREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetWidthRequest)
  })
_sym_db.RegisterMessage(GetWidthRequest)

GetWidthReply = _reflection.GeneratedProtocolMessageType('GetWidthReply', (_message.Message,), {
  'DESCRIPTOR' : _GETWIDTHREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetWidthReply)
  })
_sym_db.RegisterMessage(GetWidthReply)

GetRoadWidthRequest = _reflection.GeneratedProtocolMessageType('GetRoadWidthRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROADWIDTHREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetRoadWidthRequest)
  })
_sym_db.RegisterMessage(GetRoadWidthRequest)

GetRoadWidthReply = _reflection.GeneratedProtocolMessageType('GetRoadWidthReply', (_message.Message,), {
  'DESCRIPTOR' : _GETROADWIDTHREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetRoadWidthReply)
  })
_sym_db.RegisterMessage(GetRoadWidthReply)

GetRelativeWidthRequest = _reflection.GeneratedProtocolMessageType('GetRelativeWidthRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRELATIVEWIDTHREQUEST,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetRelativeWidthRequest)
  })
_sym_db.RegisterMessage(GetRelativeWidthRequest)

GetRelativeWidthReply = _reflection.GeneratedProtocolMessageType('GetRelativeWidthReply', (_message.Message,), {
  'DESCRIPTOR' : _GETRELATIVEWIDTHREPLY,
  '__module__' : 'proto.grpc.hdmapimpl_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetRelativeWidthReply)
  })
_sym_db.RegisterMessage(GetRelativeWidthReply)


DESCRIPTOR._options = None
_GETMAPREPLY_LINESENTRY._options = None
_GETELEMENTBYIDREPLY_LINESENTRY._options = None
_GETELEMENTSREPLY_LINESENTRY._options = None

_HDMAPIMPL = _descriptor.ServiceDescriptor(
  name='HdmapImpl',
  full_name='hdmap_lib.HdmapImpl',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5008,
  serialized_end=5910,
  methods=[
  _descriptor.MethodDescriptor(
    name='LoadMap',
    full_name='hdmap_lib.HdmapImpl.LoadMap',
    index=0,
    containing_service=None,
    input_type=_LOADMAPREQUEST,
    output_type=_LOADMAPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReleaseMap',
    full_name='hdmap_lib.HdmapImpl.ReleaseMap',
    index=1,
    containing_service=None,
    input_type=_RELEASEMAPREQUEST,
    output_type=_RELEASEMAPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Reload',
    full_name='hdmap_lib.HdmapImpl.Reload',
    index=2,
    containing_service=None,
    input_type=_RELOADREQUEST,
    output_type=_RELOADREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMap',
    full_name='hdmap_lib.HdmapImpl.GetMap',
    index=3,
    containing_service=None,
    input_type=_GETMAPREQUEST,
    output_type=_GETMAPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElementById',
    full_name='hdmap_lib.HdmapImpl.GetElementById',
    index=4,
    containing_service=None,
    input_type=_GETELEMENTBYIDREQUEST,
    output_type=_GETELEMENTBYIDREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElements',
    full_name='hdmap_lib.HdmapImpl.GetElements',
    index=5,
    containing_service=None,
    input_type=_GETELEMENTSREQUEST,
    output_type=_GETELEMENTSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Getprojection',
    full_name='hdmap_lib.HdmapImpl.Getprojection',
    index=6,
    containing_service=None,
    input_type=_GETPROJECTIONREQUEST,
    output_type=_GETPROJECTIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPoint',
    full_name='hdmap_lib.HdmapImpl.GetPoint',
    index=7,
    containing_service=None,
    input_type=_GETPOINTREQUEST,
    output_type=_GETPOINTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHeading',
    full_name='hdmap_lib.HdmapImpl.GetHeading',
    index=8,
    containing_service=None,
    input_type=_GETHEADINGREQUEST,
    output_type=_GETHEADINGREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWidth',
    full_name='hdmap_lib.HdmapImpl.GetWidth',
    index=9,
    containing_service=None,
    input_type=_GETWIDTHREQUEST,
    output_type=_GETWIDTHREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRoadWidth',
    full_name='hdmap_lib.HdmapImpl.GetRoadWidth',
    index=10,
    containing_service=None,
    input_type=_GETROADWIDTHREQUEST,
    output_type=_GETROADWIDTHREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRelativeWidth',
    full_name='hdmap_lib.HdmapImpl.GetRelativeWidth',
    index=11,
    containing_service=None,
    input_type=_GETRELATIVEWIDTHREQUEST,
    output_type=_GETRELATIVEWIDTHREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HDMAPIMPL)

DESCRIPTOR.services_by_name['HdmapImpl'] = _HDMAPIMPL

# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
#-*- coding:utf-8 -*-
import os 
from setuptools import setup, find_packages

MAJOR =0
MINOR =0
PATCH =3
VERSION = f"{MAJOR}.{MINOR}.{PATCH}"

def get_install_requires():
    reqs = [
            ]
    return reqs
setup(
	name = "fabu-pyhdmap",
	version = VERSION,
    author ="zhangqiuyang",
    author_email = "zhangqiuyang@fabu.ai",
    long_description_content_type="text/markdown",
	url = 'http://git.fabu.ai/zhangqiuyang/hdmapsdk-python',
	long_description = open('README.md',encoding="utf-8").read(),
    python_requires=">=3.7",
    install_requires=get_install_requires(),
	packages = find_packages(),
 	license = 'Apache',
    package_data={'': ['*.csv', '*.txt','.toml', "*.yaml", "*.conf"]},
    include_package_data=True
)